==> speech-sdk-0.5.12-sources.jar: com/segway/robot/sdk/voice/internal/Client.java <==
package com.segway.robot.sdk.voice.internal;

import android.util.SparseArray;

import com.segway.robot.sdk.voice.audiodata.IRawDataListener;
import com.segway.robot.sdk.voice.grammar.GrammarConstraint;
import com.segway.robot.sdk.voice.recognition.IRecognitionListener;
import com.segway.robot.sdk.voice.recognition.IWakeupListener;
import com.segway.robot.sdk.voice.recognition.RecognitionListener;
import com.segway.robot.sdk.voice.recognition.WakeupListener;

import java.util.HashMap;

/**
 * Created by ark338 on 16/9/1.
 */
public class Client {
    int mUid;
    private final HashMap<String, GrammarConstraint> mGrammarConstraintMap;
    private IWakeupListener mWakeupListener;
    private IRecognitionListener mRecognitionListener;
    private IRawDataListener mRawDataListener;

    public Client(int uid) {
        mUid = uid;
        mGrammarConstraintMap = new HashMap<>();
    }

    public int getUid() {
        return mUid;
    }

    public void addGrammarConstraint(GrammarConstraint grammarConstraint) {
        synchronized (mGrammarConstraintMap) {
            mGrammarConstraintMap.put(grammarConstraint.getName(), grammarConstraint);
        }
    }

    public void removeGrammarConstraint(GrammarConstraint grammarConstraint) {
        synchronized (mGrammarConstraintMap) {
            mGrammarConstraintMap.remove(grammarConstraint.getName());
        }
    }

    public GrammarConstraint[] getGrammarConstraints() {
        return (GrammarConstraint[]) mGrammarConstraintMap.values().toArray();
    }

    public IWakeupListener getWakeupListener() {
        return mWakeupListener;
    }

    public void setWakeupListener(IWakeupListener wakeupListener) {
        mWakeupListener = wakeupListener;
    }

    public IRecognitionListener getRecognitionListener() {
        return mRecognitionListener;
    }

    public void setRecognitionListener(IRecognitionListener recognitionListener) {
        mRecognitionListener = recognitionListener;
    }

    public void setRawDataListener(IRawDataListener rawDataListener) {
        mRawDataListener = rawDataListener;
    }

    public IRawDataListener getRawDataListener() {
        return mRawDataListener;
    }
}

==> speech-sdk-0.5.291-sources.jar: com/segway/robot/sdk/voice/internal/Client.java <==
package com.segway.robot.sdk.voice.internal;

import com.segway.robot.sdk.voice.audiodata.IRawDataListener;
import com.segway.robot.sdk.voice.grammar.GrammarConstraint;
import com.segway.robot.sdk.voice.recognition.IRecognitionListener;
import com.segway.robot.sdk.voice.recognition.IWakeupListener;

import java.util.HashMap;

/**
 * Created by ark338 on 16/9/1.
 */
public class Client {
    String mPackageName;
    private final HashMap<String, GrammarConstraint> mGrammarConstraintMap;
    private IWakeupListener mWakeupListener;
    private IRecognitionListener mRecognitionListener;
    private IRawDataListener mRawDataListener;

    public Client(String packageName) {
        mPackageName = packageName;
        mGrammarConstraintMap = new HashMap<>();
    }

    public String getPackageName() {
        return mPackageName;
    }

    public void addGrammarConstraint(GrammarConstraint grammarConstraint) {
        synchronized (mGrammarConstraintMap) {
            mGrammarConstraintMap.put(grammarConstraint.getName(), grammarConstraint);
        }
    }

    public void removeGrammarConstraint(GrammarConstraint grammarConstraint) {
        synchronized (mGrammarConstraintMap) {
            mGrammarConstraintMap.remove(grammarConstraint.getName());
        }
    }

    public GrammarConstraint[] getGrammarConstraints() {
        return (GrammarConstraint[]) mGrammarConstraintMap.values().toArray();
    }

    public IWakeupListener getWakeupListener() {
        return mWakeupListener;
    }

    public void setWakeupListener(IWakeupListener wakeupListener) {
        mWakeupListener = wakeupListener;
    }

    public IRecognitionListener getRecognitionListener() {
        return mRecognitionListener;
    }

    public void setRecognitionListener(IRecognitionListener recognitionListener) {
        mRecognitionListener = recognitionListener;
    }

    public void setRawDataListener(IRawDataListener rawDataListener) {
        mRawDataListener = rawDataListener;
    }

    public IRawDataListener getRawDataListener() {
        return mRawDataListener;
    }
}
